@@ -35,7 +35,8 @@ class DynamicSetting(object):
                  download_options=None,
                  debug_version=DEFAULT_DEBUG_VERSION,
                  fallback_allowed=False,
-                 download_timeout=1.5):
+                 download_timeout=1.5,
+                 verbose=False):
 
         self.slug = slug
         self.content = None
@@ -44,6 +45,7 @@ class DynamicSetting(object):
         self.load_time = None
         self.source = None
         self.fallback_allowed = fallback_allowed
+        self.verbose = verbose
 
         self.domain = domain
         self.url = url
@@ -76,7 +78,8 @@ class DynamicSetting(object):
                             domain,
                             data_dir,
                             logger=None,
-                            instance_id=None):
+                            instance_id=None,
+                            verbose=False):
 
         return cls(slug=obj['slug'],
                    url=obj['url'],
@@ -91,25 +94,26 @@ class DynamicSetting(object):
                    download_subkey=obj.get('subkey'),
                    version_subkey=obj.get('version'),
                    fallback_allowed=obj.get('fallback_allowed', False),
-                   download_timeout=obj.get('download_timeout', 1.5))
+                   download_timeout=obj.get('download_timeout', 1.5),
+                   verbose=verbose)
 
-    def get(self, version=None, verbose=False):
+    def get(self, version=None):
 
         if self.content is None or self.is_fallback:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Loading from storage, since content is None or this is the fallback')
-            self.load_from_storage(version, verbose=verbose)
+            self.load_from_storage(version)
 
         elif self.loaded_version_is_ok(version) and not self.too_old:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Loaded content is ok')
             return self.content
 
         else:
-            self.load_from_storage(version, verbose=verbose)
+            self.load_from_storage(version)
 
         if self.content is None:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Loading fallback')
             self.load_fallback()
 
@@ -126,16 +130,16 @@ class DynamicSetting(object):
         self.load_time = self.current_time
         self.source = source
 
-    def load_from_storage(self, version, verbose=False):
+    def load_from_storage(self, version):
 
-        self.load_from_cache(version, verbose=verbose)
+        self.load_from_cache(version)
 
         if self.content is None or self.too_old:
-            self.download(verbose=verbose)
+            self.download()
 
-    def load_from_cache(self, version, verbose=False):
+    def load_from_cache(self, version):
 
-        if verbose:
+        if self.verbose:
             print(f'{self.slug} - Loading from cache')
         try:
             data = self.redis_client.get_latest_data(
@@ -149,41 +153,41 @@ class DynamicSetting(object):
             )
             cache_version, download_time, content = self.parse_cache_data(data=data)
             source = 'cache'
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Loaded from cache')
         except (redis.connection.ConnectionError, redis.connection.TimeoutError):
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Loading from cache failed')
-            cache_version, download_time, content = self.load_from_file(verbose=verbose)
+            cache_version, download_time, content = self.load_from_file()
             source = 'disk'
 
 
         if not content is None:
 
             if self.is_larger_than_loaded_version(cache_version):
-                if verbose:
+                if self.verbose:
                     print(f'{self.slug} - Cache version larger than loaded version')
                 self.load_content(data=content,
                                   version=cache_version,
                                   download_time=download_time,
                                   source=source)
             if self.loaded_version_is_ok(version):
-                if verbose:
+                if self.verbose:
                     print(f'{self.slug} - Loaded version is ok')
                 return
 
-        self.download(verbose=verbose)
+        self.download()
 
-    def load_from_file(self, verbose=False):
+    def load_from_file(self):
 
         self.logger.warning('Loading settings from file')
-        if verbose:
+        if self.verbose:
             print(f'{self.slug} - Loading from disk')
         latest_files = [fn for fn in [self.parse_filename(filename) for filename in os.listdir(self.data_dir)
                                       if filename.endswith('.json') and filename.startswith(self.slug)
                                       and not filename.endswith('fallback.json')] if not fn is None]
         if not latest_files:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - No file to load from')
             return None, None, None
 
@@ -191,11 +195,11 @@ class DynamicSetting(object):
         try:
             with open(latest_file['file_path'], 'r') as f:
                 data = json.load(f)
-                if verbose:
+                if self.verbose:
                     print(f'{self.slug} - Loaded from disk')
                 return self.parse_data(data)
         except json.JSONDecodeError:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Invalid file on disk')
             return None, None, None
 
@@ -301,10 +305,10 @@ class DynamicSetting(object):
         except (redis.exceptions.TimeoutError, redis.exceptions.ConnectionError):
             return False
 
-    def download(self, verbose):
+    def download(self):
 
         try:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Downloading...')
             r = self.session.get(url=self.url, **self.download_options, timeout=self.download_timeout)
             r.raise_for_status()
@@ -320,13 +324,13 @@ class DynamicSetting(object):
 
         version, data = self.parse_download_data(data=data)
         if data is None:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Downloaded data invalid')
             return
 
         data = self.validate_download_data(data=data)
         if data is None:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Downloaded data did not validate')
             return
 
@@ -384,9 +388,9 @@ class DynamicSetting(object):
             'timestamp': download_time.timestamp()
         }
 
-    def write_data_to_redis(self, data, version, download_time, verbose=False):
+    def write_data_to_redis(self, data, version, download_time):
 
-        if verbose:
+        if self.verbose:
             print(f'{self.slug} - Writing data to redis')
         data = self.build_data_object(content=data, version=version, download_time=download_time)
         result = self.redis_client.set_data_with_version(
@@ -402,12 +406,12 @@ class DynamicSetting(object):
             ]
         )
         if int(result[0]) == 1:
-            if verbose:
+            if self.verbose:
                 print(f'{self.slug} - Wrote data to redis successful')
             return
 
         data = result[1]
-        if verbose:
+        if self.verbose:
             print(f'{self.slug} - Version is cache is newer')
         if not data is None:
             cache_version, download_time, content = self.parse_cache_data(data=data)
@@ -497,10 +501,10 @@ class DynamicSetting(object):
             return False, f'All values should be {type.__name__}'
         return True, None
 
-    def health(self, verbose=False):
+    def health(self):
 
         if self.content is None:
-            self.get(version=self.debug_version, verbose=verbose)
+            self.get(version=self.debug_version)
 
         healthy = False
 
